<?php

/**
 * Fired during plugin instalation
 *
 * @link 		https://lin3s.com
 * @since 		1.0.0
 *
 * @package 	Alexandria_Mail_Builder
 * @subpackage 	Alexandria_Mail_Builder/includes
 */

class Alexandria_Mail_Builder_Cpt {

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		public
	 * @var 		string 			$plugin_name 		The string used to uniquely identify this plugin.
	 */
	public $cutoms_taxonomies_list;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		public
	 * @var 		string 			$plugin_name 		The string used to uniquely identify this plugin.
	 */
	public $custom_posts_types_list;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		public
	 * @var 		string 			$plugin_name 		The string used to uniquely identify this plugin.
	 */
	public $plugin_name;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		public
	 * @var 		string 			$plugin_name 		The string used to uniquely identify this plugin.
	 */
	public $version;

	/**
	 * Initialize the custom post type list
	 *
	 * @since 		1.0.0
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		$this->custom_posts_types_list = [
			'num_post_types' => 16,
			'post_types' => [

				'singular' => [
					'Email',
					'Interlocutor',
					'Situación',
					'Tono',
					'Gran Idea - Email',
					'Soliloquio',
					'Argumento - Email',
					'Caja de Contenidos',
					'Caja de Engagement',
					'Ingrediente',
					'Argumento - Pitch',
					'Gran Idea - Pitch',
					'Llamada a la Acción',
					'Comentario',
					'Ejemplo',
					'Objectivo Builder'
				],

				'plural' => [
					'Emails',
					'Interlocutores',
					'Situaciones',
					'Tonos',
					'Gran Ideas - Email',
					'Soliloquios',
					'Argumentos - Email',
					'Cajas de Contenido',
					'Cajas de Engagement',
					'Ingredientes',
					'Argumentos - Pitch',
					'Gran Ideas - Pitch',
					'Llamadas a la acción',
					'Comentarios',
					'Ejemplos',
					'Objectivos Builder'
				],

				'post_type_name' => [
					'emails',
					'interlocutors_email',
					'situations_email',
					'tonos_email',
					'gran_ideas_email',
					'soliloquios_email',
					'arguments_email',
					'content_boxes',
					'engagement_boxes',
					'ingredients',
					'arguments_pitch',
					'gran_ideas_pitch',
					'call_to_action_email',
					'comments_email',
					'examples_email',
					'objectives_email'
				]

			]
		];


		$this->cutoms_taxonomies_list = [
			'num_taxonomies' => 1,
			'taxonomies' => [

				'singular' => [
					'Tipo Situación'
				],

				'plural' => [
					'Tipos Situaciones'
				],

				'taxonomy_name' => [
					'situations-email-categories'
				],

				'post_type_name' => [
					'situations_email'
				]

			]
		];

	}

	/**
	 * Register all custom taxonomies of the plugin.
	 *
	 * @since 		1.0.0
	 * @access 		public
	 */
	public function register_custom_post_types() {

		$cutom_post_types_list = $this->custom_posts_types_list;

		for ( $i=0; $i <= ($cutom_post_types_list['num_post_types'] - 1); $i++) {

			$post_type_name = $cutom_post_types_list['post_types']['post_type_name'][$i];
			$singular = $cutom_post_types_list['post_types']['singular'][$i];
			$plural = $cutom_post_types_list['post_types']['plural'][$i];

			$labels = array(
				'name'                  => _x( $plural, 'Post Type General Name', 'alexandria-mail-builder' ),
				'singular_name'         => _x( $singular, 'Post Type Singular Name', 'alexandria-mail-builder' ),
				'add_new'               => __( 'Nuevo '.$singular, 'alexandria-mail-builder' ),
				'add_new_item'          => __( 'Añadir Nuevo '.$singular, 'alexandria-mail-builder' ),
				'edit_item'             => __( 'Editar '.$singular, 'alexandria-mail-builder' ),
				'new_item'              => __( 'Nuevo '.$singular, 'alexandria-mail-builder' ),
				'view_item'             => __( 'Ver '.$singular, 'alexandria-mail-builder' ),
				'view_items'            => __( 'Ver '.$plural, 'alexandria-mail-builder' ),
				'search_items'          => __( 'Buscar '.$plural, 'alexandria-mail-builder' ),
				"not_found"             => "No plural Found",
				"not_found_in_trash"    => "No plural Found in Trash",
				'all_items'             => "All plural",
				'attributes'            => "singular Attributes",
				'insert_into_item'      => "Insert to singular",
				'uploaded_to_this_item' => "Uploaded to this singular"
			);

			$supports = array('title');

			if($post_type_name === 'examples_email' || $post_type_name === 'objectives_email' || $post_type_name === 'arguments_pitch' || $post_type_name === 'arguments_email') {

				$supports = array('title', 'editor');

			}

			$args = array(
				'label'               => $singular,
				'description'         => __( $singular.' del plugin de Alexandria', 'alexandria-mail-builder' ),
				'labels'              => $labels,
				'supports'            => $supports,
				'hierarchical'        => false,
				'public'              => false,
				'show_ui'             => true,
				'show_in_menu'        => false,
				'show_in_nav_menus'   => false,
				'show_in_admin_bar'   => false,
				'menu_position'       => 30,
				'can_export'          => true,
				'has_archive'         => true,
				'exclude_from_search' => true,
				'publicly_queryable'  => false,
				'capability_type'     => 'post',
				'show_in_rest' 		  => true
			);

			register_post_type($post_type_name, $args);
		}

	}


	/**
	 * Register all custom taxonomies of the plugin.
	 *
	 * @since 		1.0.0
	 * @access 		public
	 */
	public function register_custom_taxonomies() {

		$cutoms_taxonomies_list = $this->cutoms_taxonomies_list;

		for ( $i=0; $i <= ($cutoms_taxonomies_list['num_taxonomies'] - 1); $i++) {

			$taxonomy_name = $cutoms_taxonomies_list['taxonomies']['taxonomy_name'][$i];
			$singular = $cutoms_taxonomies_list['taxonomies']['singular'][$i];
			$plural = $cutoms_taxonomies_list['taxonomies']['plural'][$i];
			$post_type_name = $cutoms_taxonomies_list['taxonomies']['post_type_name'][$i];

			register_taxonomy( $taxonomy_name,
				array (0 => $post_type_name),
				array(
					'hierarchical'      		 => true,
					'label'             		 => __( $singular, 'alexandria-mail-builder' ),
					'show_ui'           		 => true,
					'query_var'         		 => true,
					'show_admin_column' 		 => true,
					'sortable' 					 => true,
					'labels'            		 => array (
						'search_items'               => __('Buscar '.$plural, 'alexandria-mail-builder'),
						'popular_items'              => __('Más Populares', 'alexandria-mail-builder'),
						'all_items'                  => __('Todas las '.$plural, 'alexandria-mail-builder'),
						'parent_item'                => __('Superior', 'alexandria-mail-builder'),
						'parent_item_colon'          => __( $singular.' Superior', 'alexandria-mail-builder'),
						'edit_item'                  => __('Editar '.$singular, 'alexandria-mail-builder'),
						'update_item'                => __('Actualizar '.$singular, 'alexandria-mail-builder'),
						'add_new_item'               => __('Añadir '.$singular, 'alexandria-mail-builder'),
						'new_item_name'              => __('Nueva '.$singular, 'alexandria-mail-builder'),
						'separate_items_with_commas' => __('Separar categorías con comas', 'alexandria-mail-builder'),
						'add_or_remove_items'        => __('Añadir o Eliminar', 'alexandria-mail-builder'),
						'choose_from_most_used'      => __('Elegir de las categorías más usadas', 'alexandria-mail-builder'),
					)
				));

		}

	} // define_custom_taxonomies()

	/**
	 * Register all metaboxes of the plugin.
	 *
	 * @since 		1.0.0
	 * @access 		public
	 */
	public function define_custom_post_type_mataboxes() {

		// E-Mails Metaboxes
		$emails_metaboxes = new Alexandria_Mail_Mails_Metaboxes( $this->plugin_name, $this->version );

		add_meta_box('interlocutor_metabox', __( 'Interlocutor del E-mail', 'alexandria-mail-builder' ), array( $emails_metaboxes, 'interlocutor_fields' ), 'emails' );
		
		add_meta_box('tono_metabox', __( 'Tono del E-mail', 'alexandria-mail-builder' ), array( $emails_metaboxes, 'tono_fields' ), 'emails' );

		add_meta_box('situation_metabox', __( 'Situación del E-mail', 'alexandria-mail-builder' ), array( $emails_metaboxes, 'situation_fields' ), 'emails' );

		add_meta_box('gran_idea_email_metabox', __( 'Gran Idea del E-mail', 'alexandria-mail-builder' ), array( $emails_metaboxes, 'gran_idea_email_fields' ), 'emails' );

		add_meta_box('arguments_email_metabox', __( 'Argumentos del E-mail', 'alexandria-mail-builder' ), array( $emails_metaboxes, 'arguments_email_fields' ), 'emails' );

		add_meta_box('content_boxes_metabox', __( 'Cajas de Contenidos del E-mail', 'alexandria-mail-builder' ), array( $emails_metaboxes, 'content_boxes_fields' ), 'emails' );

		add_meta_box('engagement_boxes_metabox', __( 'Cajas de Engagement del E-mail', 'alexandria-mail-builder' ), array( $emails_metaboxes, 'engagement_boxes_fields' ), 'emails' );

		add_meta_box('ingredients_metabox', __( 'Ingredientes del E-mail', 'alexandria-mail-builder' ), array( $emails_metaboxes, 'ingredients_fields' ), 'emails' );

		add_meta_box('soliloquios_metabox', __( 'Soliloquios del E-mail', 'alexandria-mail-builder' ), array( $emails_metaboxes, 'soliloquios_fields' ), 'emails' );

		add_meta_box('gran_idea_pitch_metabox', __( 'Gran Idea - Pitch', 'alexandria-mail-builder' ), array( $emails_metaboxes, 'gran_idea_pitch_fields' ), 'emails' );

		add_meta_box('arguments_pitch_metabox', __( 'Argumentos - Pitch del E-mail', 'alexandria-mail-builder' ), array( $emails_metaboxes, 'arguments_pitch_fields' ), 'emails' );

		add_meta_box('call_to_action_metabox', __( 'Llamadas a la acción del E-mail', 'alexandria-mail-builder' ), array( $emails_metaboxes, 'call_to_action_fields' ), 'emails' );

		add_meta_box('email_builder_examples_metabox', __( 'Ejemplos del E-mail', 'alexandria-mail-builder' ), array( $emails_metaboxes, 'email_builder_examples_fields' ), 'emails' );

		add_meta_box('alexandria_email_comments_metabox', __( 'Comentarios del E-mail', 'alexandria-mail-builder' ), array( $emails_metaboxes, 'alexandria_email_comments_fields' ), 'emails' );

		// Tonos Metaboxes
		$tono_email_metabox = new Alexandria_Mail_Tonos_Metaboxes( $this->plugin_name, $this->version );

		add_meta_box('tonos-colors-metabox', __('Colores de la Emoción', 'alexandria-mail-builder' ), array( $tono_email_metabox, 'alexandria_email_tonos_colors_meta_box' ), 'tonos_email');

		// Interlocutors Metaboxes
		$interlocutors_emails_metabox = new Alexandria_Mail_Interlocutors_Email_Metaboxes( $this->plugin_name, $this->version );

		add_meta_box('interlocutors-emails-metabox', __('Orden del interlocutor', 'alexandria-mail-builder' ), array( $interlocutors_emails_metabox, 'alexandria_email_interlocutors_meta_box' ), 'interlocutors_email');


	} // define_custom_post_type_mataboxes()
}
