<?php

/**
 * E-Mail Landing Page template.
 *
 * @package Alexandria_Mail_Builder
 * @subpackage Alexandria_Mail_Builder/public/templates
 */

if ( ! defined( 'ABSPATH' ) ) { exit; } // Exit if accessed directly

// Check if wp-membership is active
if ( is_plugin_active('simple-membership/simple-wp-membership.php') ) {
	do_action('alexandria_check_membership_plugin');
}

$plugin_name = "alexandria-mail-builder";

$button_bg_color =  get_option( $plugin_name.'_button_bg_color' ) ?  get_option( $plugin_name.'_button_bg_color' ) : '#6628DD';
$button_text_color = get_option( $plugin_name.'_button_text_color' ) ?  get_option( $plugin_name.'_button_text_color' ) : '#FFFFFF';
$button_border_color = get_option( $plugin_name.'_button_border_color' ) ?  get_option( $plugin_name.'_button_border_color' ) : '#6628DD';

$button_bg_hover_color = get_option( $plugin_name.'_button_bg_hover_color' ) ?  get_option( $plugin_name.'_button_bg_hover_color' ) : '#FFFFFF';
$button_hover_text_color = get_option( $plugin_name.'_button_hover_text_color' ) ?  get_option( $plugin_name.'_button_hover_text_color' ) : '#6628DD';
$button_hover_border_color = get_option( $plugin_name.'_button_hover_border_color' ) ?  get_option( $plugin_name.'_button_hover_border_color' ) : '#6628DD';

$image_id = get_option( $plugin_name.'_header_background_image' ) ?  get_option( $plugin_name.'_header_background_image' ) : '';

$image_url = $image_id == '' ? ALEXANDRIA_MAIL_BUILDER_PUBLIC_URL.'assets/images/landing_header.jpg' : wp_get_attachment_url($image_id);

$header_bg_color = get_option( $plugin_name.'_color_barra_cabecera_interior' ) ?  get_option( $plugin_name.'_color_barra_cabecera_interior' ) : '#FF0000';

$header_text_color = get_option( $plugin_name.'_color_texto_barra_cabecera_interior' ) ? get_option( $plugin_name .'_color_texto_barra_cabecera_interior' ) : '#FFFFFF';

?>

<style>
	.alexandria-title-block::before {
		background-image: url('<?php echo $image_url; ?>');
	}

	#alexandria-title-overlay {
		background-color: #383838;
	}

	.alexandria-email-start-game-button {
		background-color: <?php echo $button_bg_color; ?>;
		border: 1px solid <?php echo $button_border_color; ?>;
		color: <?php echo $button_text_color; ?>;
	}

	.alexandria-email-start-game-button:hover {
		background-color: <?php echo $button_bg_hover_color ?>;
		border: 1px solid <?php echo $button_hover_border_color; ?>;
		color: <?php echo $button_hover_text_color; ?>;
	}

	.alexandria-mail-builder-sticky-header {
		background-color: <?php echo $header_bg_color; ?>;
	}

	.alexandria-close-cross::before {
		background-color: <?php echo $header_text_color; ?> !important;
	}

	.alexandria-close-cross::after {
		background-color: <?php echo $header_text_color; ?> !important;
	}

	.alexandria-title-text {
		color: <?php echo $header_text_color; ?>;
	}
</style>

<!-- Main Builder Section -->
<div id="alexandria_mail_builder_main" class="alexandria-mail-builder__container">

	<div class="alexandria-mail-builder__wrapper">
		
		<!-- Title Section -->
		<?php include 'layouts/landing_header.php' ?>
		<!-- End Title Section -->

		<!-- Landing Content Section -->
		<section class="alexandria-mail-builder__landing-content">

			<div class="alexandria-mail-builder__landing-content__wrapper">

				<div class="alexandria-mail-builder__landing-content__description">
					<span><?php _e('Descripción', 'alexandria-mail-builder' ); ?></span>
					<p>
						<?php echo get_option( $plugin_name.'_descripcion_portada' ); ?>
					</p>
				</div>

				<div class="alexandria-mail-builder__landing-content__button-wrapper">

					<button type="button" class="alexandria-mail-builder-start-game-button">
						<?php echo get_option( $plugin_name.'_button_text' ); ?>
					</button>

				</div>

				<!-- Objectives section -->
				<?php include 'partials/objectives-grid.php' ?>
				<!-- End Objectives section -->

				<div class="alexandria-mail-builder__landing-content__button-wrapper--bottom">

					<button type="button" class="alexandria-mail-builder-start-game-button" >
						<?php echo get_option( $plugin_name.'_button_text' ); ?>
					</button>

				</div>

			</div>

		</section>
		<!-- End Landing Content Section -->

	</div>

	<!-- End Loader Spinner -->
	<?php include 'elements/loading-spinner.php' ?>
	<!-- End Loader Spinner section -->

</div>
<!-- End Main Builder Section -->

